@@ -90,9 +90,10 @@ def create_run(name, project_path, token):
                 body_args=dict(name=name))
     return res
 
-def pulse(path, project_path, token):
+def pulse(path, project_path, keys, token):
     res = lab_request(path=f"/{project_path}/runs/{path}/heartbeat", 
-                request_type="POST", 
+                request_type="POST",
+                body_args=dict(keys=keys),
                 token=token)
     return res
 
