@@ -39,7 +39,8 @@ class PulseManager():
 
     @silent_method_if_dry
     def send_beat(self):
-        new_messages = self.events_manager.add_event("pulse", (self.run_path, self.project), async_method=False)
+        keys = list(self.messages.keys())
+        new_messages = self.events_manager.add_event("pulse", (self.run_path, self.project, keys), async_method=False)
         new_messages.pop("status_code")
         for key, item in new_messages.items():
             self.messages[key] = item
\ No newline at end of file
