@@ -13,7 +13,7 @@ class RepeatedTimer(threading.Thread):
             self.method()
             
     def stopped(self):
-        return self._stopper.isSet()
+        return self._stopper.is_set()
 
     def stop(self):
         self._stopper.set()
\ No newline at end of file
